==> vb-react-form-0.0.3.tgz: package/es/fields.js <==
import _objectWithoutProperties from "babel-runtime/helpers/objectWithoutProperties";
import _extends from "babel-runtime/helpers/extends";
import _classCallCheck from "babel-runtime/helpers/classCallCheck";
import _possibleConstructorReturn from "babel-runtime/helpers/possibleConstructorReturn";
import _inherits from "babel-runtime/helpers/inherits";
import React from 'react';

var FieldInput = function (_React$Component) {
  _inherits(FieldInput, _React$Component);

  function FieldInput() {
    var _temp, _this, _ret;

    _classCallCheck(this, FieldInput);

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return _ret = (_temp = (_this = _possibleConstructorReturn(this, _React$Component.call.apply(_React$Component, [this].concat(args))), _this), _this.onChange = function (event) {
      _this.props.onChange(event.target.value, event);
    }, _temp), _possibleConstructorReturn(_this, _ret);
  }

  FieldInput.prototype.render = function render() {
    return React.createElement("input", _extends({ type: "text" }, this.props, { onChange: this.onChange }));
  };

  return FieldInput;
}(React.Component);

var FieldText = function (_React$Component2) {
  _inherits(FieldText, _React$Component2);

  function FieldText() {
    var _temp2, _this2, _ret2;

    _classCallCheck(this, FieldText);

    for (var _len2 = arguments.length, args = Array(_len2), _key2 = 0; _key2 < _len2; _key2++) {
      args[_key2] = arguments[_key2];
    }

    return _ret2 = (_temp2 = (_this2 = _possibleConstructorReturn(this, _React$Component2.call.apply(_React$Component2, [this].concat(args))), _this2), _this2.onChange = function (event) {
      _this2.props.onChange(event.target.value, event);
    }, _temp2), _possibleConstructorReturn(_this2, _ret2);
  }

  FieldText.prototype.render = function render() {
    return React.createElement("textarea", _extends({}, this.props, { onChange: this.onChange }));
  };

  return FieldText;
}(React.Component);

var FieldRadio = function (_React$Component3) {
  _inherits(FieldRadio, _React$Component3);

  function FieldRadio() {
    var _temp3, _this3, _ret3;

    _classCallCheck(this, FieldRadio);

    for (var _len3 = arguments.length, args = Array(_len3), _key3 = 0; _key3 < _len3; _key3++) {
      args[_key3] = arguments[_key3];
    }

    return _ret3 = (_temp3 = (_this3 = _possibleConstructorReturn(this, _React$Component3.call.apply(_React$Component3, [this].concat(args))), _this3), _this3.onChange = function (event) {
      _this3.props.onChange(event.target.checked, event);
    }, _temp3), _possibleConstructorReturn(_this3, _ret3);
  }

  FieldRadio.prototype.render = function render() {
    return React.createElement("input", _extends({ checked: this.props.value }, this.props, { type: "radio", onChange: this.onChange }));
  };

  return FieldRadio;
}(React.Component);

var FieldCheckbox = function (_React$Component4) {
  _inherits(FieldCheckbox, _React$Component4);

  function FieldCheckbox() {
    var _temp4, _this4, _ret4;

    _classCallCheck(this, FieldCheckbox);

    for (var _len4 = arguments.length, args = Array(_len4), _key4 = 0; _key4 < _len4; _key4++) {
      args[_key4] = arguments[_key4];
    }

    return _ret4 = (_temp4 = (_this4 = _possibleConstructorReturn(this, _React$Component4.call.apply(_React$Component4, [this].concat(args))), _this4), _this4.onChange = function (event) {
      _this4.props.onChange(event.target.checked, event);
    }, _temp4), _possibleConstructorReturn(_this4, _ret4);
  }

  FieldCheckbox.prototype.render = function render() {
    return React.createElement("input", _extends({ checked: this.props.value }, this.props, { type: "checkbox", onChange: this.onChange }));
  };

  return FieldCheckbox;
}(React.Component);

var FieldRadioGroup = function (_React$Component5) {
  _inherits(FieldRadioGroup, _React$Component5);

  function FieldRadioGroup() {
    var _temp5, _this5, _ret5;

    _classCallCheck(this, FieldRadioGroup);

    for (var _len5 = arguments.length, args = Array(_len5), _key5 = 0; _key5 < _len5; _key5++) {
      args[_key5] = arguments[_key5];
    }

    return _ret5 = (_temp5 = (_this5 = _possibleConstructorReturn(this, _React$Component5.call.apply(_React$Component5, [this].concat(args))), _this5), _this5.onChange = function (event) {
      _this5.props.onChange(event.target.value, event);
    }, _temp5), _possibleConstructorReturn(_this5, _ret5);
  }

  FieldRadioGroup.prototype.render = function render() {
    var _this6 = this;

    var _props = this.props,
        options = _props.options,
        value = _props.value,
        other = _objectWithoutProperties(_props, ["options", "value"]);

    return React.createElement(
      "div",
      null,
      options.map(function (option, index) {
        return React.createElement(
          "div",
          { className: "radio", key: index },
          React.createElement(
            "label",
            null,
            React.createElement("input", _extends({ checked: option.value === value,
              value: option.value }, other, { type: "radio", onChange: _this6.onChange })),
            option.label
          )
        );
      })
    );
  };

  return FieldRadioGroup;
}(React.Component);

var FieldCheckboxGroup = function (_React$Component6) {
  _inherits(FieldCheckboxGroup, _React$Component6);

  function FieldCheckboxGroup() {
    var _temp6, _this7, _ret6;

    _classCallCheck(this, FieldCheckboxGroup);

    for (var _len6 = arguments.length, args = Array(_len6), _key6 = 0; _key6 < _len6; _key6++) {
      args[_key6] = arguments[_key6];
    }

    return _ret6 = (_temp6 = (_this7 = _possibleConstructorReturn(this, _React$Component6.call.apply(_React$Component6, [this].concat(args))), _this7), _this7.onChange = function (event) {
      var value = (_this7.props.value || []).slice(0);
      if (value.indexOf(event.target.value) === -1) {
        value.push(event.target.value);
      } else {
        value.splice(value.indexOf(event.target.value), 1);
      }
      _this7.props.onChange(value, event);
    }, _temp6), _possibleConstructorReturn(_this7, _ret6);
  }

  FieldCheckboxGroup.prototype.render = function render() {
    var _this8 = this;

    var _props2 = this.props,
        options = _props2.options,
        _props2$value = _props2.value,
        value = _props2$value === undefined ? [] : _props2$value,
        other = _objectWithoutProperties(_props2, ["options", "value"]);

    return React.createElement(
      "div",
      null,
      options.map(function (option, index) {
        return React.createElement(
          "div",
          { className: "checkbox", key: index },
          React.createElement(
            "label",
            null,
            React.createElement("input", _extends({ checked: value.indexOf(option.value) !== -1,
              value: option.value }, other, { type: "checkbox", onChange: _this8.onChange })),
            option.label
          )
        );
      })
    );
  };

  return FieldCheckboxGroup;
}(React.Component);

var FieldSelect = function (_React$Component7) {
  _inherits(FieldSelect, _React$Component7);

  function FieldSelect() {
    var _temp7, _this9, _ret7;

    _classCallCheck(this, FieldSelect);

    for (var _len7 = arguments.length, args = Array(_len7), _key7 = 0; _key7 < _len7; _key7++) {
      args[_key7] = arguments[_key7];
    }

    return _ret7 = (_temp7 = (_this9 = _possibleConstructorReturn(this, _React$Component7.call.apply(_React$Component7, [this].concat(args))), _this9), _this9.onChange = function (event) {
      var multiple = _this9.props.multiple;

      if (multiple) {
        var options = [].concat(event.target.options);
        var value = [];
        options.forEach(function (option) {
          if (option.selected) {
            value.push(option.value);
          }
        });
        _this9.props.onChange(value, event);
      } else {
        _this9.props.onChange(event.target.value, event);
      }
    }, _temp7), _possibleConstructorReturn(_this9, _ret7);
  }

  FieldSelect.prototype.render = function render() {
    var _props3 = this.props,
        options = _props3.options,
        _props3$value = _props3.value,
        value = _props3$value === undefined ? '' : _props3$value,
        multiple = _props3.multiple,
        other = _objectWithoutProperties(_props3, ["options", "value", "multiple"]);

    var selectValue = value;
    if (multiple && !selectValue) {
      selectValue = [];
    }
    return React.createElement(
      "select",
      _extends({}, other, { value: selectValue, multiple: multiple, onChange: this.onChange }),
      options.map(function (option, index) {
        return React.createElement(
          "option",
          { key: index, value: option.value },
          option.label
        );
      })
    );
  };

  return FieldSelect;
}(React.Component);

export { FieldInput, FieldText, FieldRadio, FieldCheckbox, FieldSelect, FieldRadioGroup, FieldCheckboxGroup };

==> vb-react-form-0.0.8.tgz: package/es/fields.js <==
import _Array$from from "babel-runtime/core-js/array/from";
import _objectWithoutProperties from "babel-runtime/helpers/objectWithoutProperties";
import _extends from "babel-runtime/helpers/extends";
import _classCallCheck from "babel-runtime/helpers/classCallCheck";
import _possibleConstructorReturn from "babel-runtime/helpers/possibleConstructorReturn";
import _inherits from "babel-runtime/helpers/inherits";
import React from 'react';

var FieldInput = function (_React$Component) {
  _inherits(FieldInput, _React$Component);

  function FieldInput() {
    var _temp, _this, _ret;

    _classCallCheck(this, FieldInput);

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return _ret = (_temp = (_this = _possibleConstructorReturn(this, _React$Component.call.apply(_React$Component, [this].concat(args))), _this), _this.onChange = function (event) {
      _this.props.onChange(event.target.value, event);
    }, _temp), _possibleConstructorReturn(_this, _ret);
  }

  FieldInput.prototype.render = function render() {
    return React.createElement("input", _extends({ type: "text" }, this.props, { onChange: this.onChange }));
  };

  return FieldInput;
}(React.Component);

var FieldText = function (_React$Component2) {
  _inherits(FieldText, _React$Component2);

  function FieldText() {
    var _temp2, _this2, _ret2;

    _classCallCheck(this, FieldText);

    for (var _len2 = arguments.length, args = Array(_len2), _key2 = 0; _key2 < _len2; _key2++) {
      args[_key2] = arguments[_key2];
    }

    return _ret2 = (_temp2 = (_this2 = _possibleConstructorReturn(this, _React$Component2.call.apply(_React$Component2, [this].concat(args))), _this2), _this2.onChange = function (event) {
      _this2.props.onChange(event.target.value, event);
    }, _temp2), _possibleConstructorReturn(_this2, _ret2);
  }

  FieldText.prototype.render = function render() {
    return React.createElement("textarea", _extends({}, this.props, { onChange: this.onChange }));
  };

  return FieldText;
}(React.Component);

var FieldRadio = function (_React$Component3) {
  _inherits(FieldRadio, _React$Component3);

  function FieldRadio() {
    var _temp3, _this3, _ret3;

    _classCallCheck(this, FieldRadio);

    for (var _len3 = arguments.length, args = Array(_len3), _key3 = 0; _key3 < _len3; _key3++) {
      args[_key3] = arguments[_key3];
    }

    return _ret3 = (_temp3 = (_this3 = _possibleConstructorReturn(this, _React$Component3.call.apply(_React$Component3, [this].concat(args))), _this3), _this3.onChange = function (event) {
      _this3.props.onChange(event.target.checked, event);
    }, _temp3), _possibleConstructorReturn(_this3, _ret3);
  }

  FieldRadio.prototype.render = function render() {
    return React.createElement("input", _extends({ checked: this.props.value }, this.props, { type: "radio", onChange: this.onChange }));
  };

  return FieldRadio;
}(React.Component);

var FieldCheckbox = function (_React$Component4) {
  _inherits(FieldCheckbox, _React$Component4);

  function FieldCheckbox() {
    var _temp4, _this4, _ret4;

    _classCallCheck(this, FieldCheckbox);

    for (var _len4 = arguments.length, args = Array(_len4), _key4 = 0; _key4 < _len4; _key4++) {
      args[_key4] = arguments[_key4];
    }

    return _ret4 = (_temp4 = (_this4 = _possibleConstructorReturn(this, _React$Component4.call.apply(_React$Component4, [this].concat(args))), _this4), _this4.onChange = function (event) {
      _this4.props.onChange(event.target.checked, event);
    }, _temp4), _possibleConstructorReturn(_this4, _ret4);
  }

  FieldCheckbox.prototype.render = function render() {
    return React.createElement("input", _extends({ checked: this.props.value }, this.props, { type: "checkbox", onChange: this.onChange }));
  };

  return FieldCheckbox;
}(React.Component);

var FieldRadioGroup = function (_React$Component5) {
  _inherits(FieldRadioGroup, _React$Component5);

  function FieldRadioGroup() {
    var _temp5, _this5, _ret5;

    _classCallCheck(this, FieldRadioGroup);

    for (var _len5 = arguments.length, args = Array(_len5), _key5 = 0; _key5 < _len5; _key5++) {
      args[_key5] = arguments[_key5];
    }

    return _ret5 = (_temp5 = (_this5 = _possibleConstructorReturn(this, _React$Component5.call.apply(_React$Component5, [this].concat(args))), _this5), _this5.onChange = function (event) {
      _this5.props.onChange(event.target.value, event);
    }, _temp5), _possibleConstructorReturn(_this5, _ret5);
  }

  FieldRadioGroup.prototype.render = function render() {
    var _this6 = this;

    var _props = this.props,
        options = _props.options,
        value = _props.value,
        other = _objectWithoutProperties(_props, ["options", "value"]);

    return React.createElement(
      "div",
      null,
      options.map(function (option, index) {
        return React.createElement(
          "div",
          { className: "radio", key: index },
          React.createElement(
            "label",
            null,
            React.createElement("input", _extends({ checked: option.value === value,
              value: option.value }, other, { type: "radio", onChange: _this6.onChange })),
            option.label
          )
        );
      })
    );
  };

  return FieldRadioGroup;
}(React.Component);

var FieldCheckboxGroup = function (_React$Component6) {
  _inherits(FieldCheckboxGroup, _React$Component6);

  function FieldCheckboxGroup() {
    var _temp6, _this7, _ret6;

    _classCallCheck(this, FieldCheckboxGroup);

    for (var _len6 = arguments.length, args = Array(_len6), _key6 = 0; _key6 < _len6; _key6++) {
      args[_key6] = arguments[_key6];
    }

    return _ret6 = (_temp6 = (_this7 = _possibleConstructorReturn(this, _React$Component6.call.apply(_React$Component6, [this].concat(args))), _this7), _this7.onChange = function (event) {
      var value = (_this7.props.value || []).slice(0);
      if (value.indexOf(event.target.value) === -1) {
        value.push(event.target.value);
      } else {
        value.splice(value.indexOf(event.target.value), 1);
      }
      _this7.props.onChange(value, event);
    }, _temp6), _possibleConstructorReturn(_this7, _ret6);
  }

  FieldCheckboxGroup.prototype.render = function render() {
    var _this8 = this;

    var _props2 = this.props,
        options = _props2.options,
        _props2$value = _props2.value,
        value = _props2$value === undefined ? [] : _props2$value,
        other = _objectWithoutProperties(_props2, ["options", "value"]);

    return React.createElement(
      "div",
      null,
      options.map(function (option, index) {
        return React.createElement(
          "div",
          { className: "checkbox", key: index },
          React.createElement(
            "label",
            null,
            React.createElement("input", _extends({ checked: value.indexOf(option.value) !== -1,
              value: option.value }, other, { type: "checkbox", onChange: _this8.onChange })),
            option.label
          )
        );
      })
    );
  };

  return FieldCheckboxGroup;
}(React.Component);

var FieldSelect = function (_React$Component7) {
  _inherits(FieldSelect, _React$Component7);

  function FieldSelect() {
    var _temp7, _this9, _ret7;

    _classCallCheck(this, FieldSelect);

    for (var _len7 = arguments.length, args = Array(_len7), _key7 = 0; _key7 < _len7; _key7++) {
      args[_key7] = arguments[_key7];
    }

    return _ret7 = (_temp7 = (_this9 = _possibleConstructorReturn(this, _React$Component7.call.apply(_React$Component7, [this].concat(args))), _this9), _this9.onChange = function (event) {
      event.preventDefault();
      var multiple = _this9.props.multiple;

      if (multiple) {
        var options = _Array$from(event.target.options);
        var value = [];
        options.forEach(function (option) {
          if (option.selected) {
            value.push(option.value);
          }
        });
        _this9.props.onChange(value, event);
      } else {
        _this9.props.onChange(event.target.value, event);
      }
    }, _temp7), _possibleConstructorReturn(_this9, _ret7);
  }

  FieldSelect.prototype.render = function render() {
    var _props3 = this.props,
        options = _props3.options,
        _props3$value = _props3.value,
        value = _props3$value === undefined ? '' : _props3$value,
        multiple = _props3.multiple,
        other = _objectWithoutProperties(_props3, ["options", "value", "multiple"]);

    var selectValue = value;
    if (multiple && !selectValue) {
      selectValue = [];
    }
    return React.createElement(
      "select",
      _extends({}, other, { value: selectValue, multiple: multiple, onChange: this.onChange }),
      options.map(function (option, index) {
        return React.createElement(
          "option",
          { key: index, value: option.value },
          option.label
        );
      })
    );
  };

  return FieldSelect;
}(React.Component);

export { FieldInput, FieldText, FieldRadio, FieldCheckbox, FieldSelect, FieldRadioGroup, FieldCheckboxGroup };
